@@ -63,7 +63,7 @@ class DataFrameSummary(object):
 
     def _get_pairplot(self):
         for i in self.df.columns:
-            if(self.df[i].nunique/data.shape[0])*100>20:
+            if(self.df[i].nunique/self.df.shape[0])*100>20:
                self.continuous.append(i)
             else:
                self.categorical.append(i)
